@@ -7,6 +7,7 @@ import json
 import compas.geometry
 from compas.base import Base
 from compas.datastructures import Mesh
+from compas.files.urdf import URDFElement
 from compas.files.urdf import URDFGenericElement
 from compas.geometry import Frame
 from compas.geometry import Shape
@@ -90,6 +91,13 @@ class Origin(Frame):
     def __init__(self, point, xaxis, yaxis):
         super(Origin, self).__init__(point, xaxis, yaxis)
 
+    def get_urdf_element(self):
+        attributes = {
+            'xyz': "{} {} {}".format(self.point.x, self.point.y, self.point.z),
+            'rpy': "{} {} {}".format(*self.euler_angles())
+        }
+        return URDFElement('origin', attributes)
+
     @classmethod
     def from_urdf(cls, attributes, elements, text):
         """Create origin instance from an URDF element.
@@ -204,6 +212,10 @@ class Box(BaseShape):
         self.size = _parse_floats(size)
         self.geometry = compas.geometry.Box(Frame.worldXY(), *self.size)
 
+    def get_urdf_element(self):
+        attributes = {'size': '{} {} {}'.format(*self.size)}
+        return URDFElement('box', attributes)
+
     @property
     def data(self):
         return {
@@ -223,6 +235,10 @@ class Box(BaseShape):
         box.data = data
         return box
 
+    @classmethod
+    def from_geometry(cls, geometry):
+        return cls(' '.join([str(geometry.xsize), str(geometry.ysize), str(geometry.zsize)]))
+
 
 class Cylinder(BaseShape):
     """3D shape primitive representing a cylinder.
@@ -258,6 +274,10 @@ class Cylinder(BaseShape):
         circle = compas.geometry.Circle(plane, self.radius)
         self.geometry = compas.geometry.Cylinder(circle, self.length)
 
+    def get_urdf_element(self):
+        attributes = {'radius': self.radius, 'length': self.length}
+        return URDFElement('cylinder', attributes)
+
     @property
     def data(self):
         return {
@@ -279,6 +299,10 @@ class Cylinder(BaseShape):
         cyl.data = data
         return cyl
 
+    @classmethod
+    def from_geometry(cls, geometry):
+        return cls(geometry.radius, geometry.height)
+
 
 class Sphere(BaseShape):
     """3D shape primitive representing a sphere.
@@ -307,6 +331,10 @@ class Sphere(BaseShape):
         self.radius = float(radius)
         self.geometry = compas.geometry.Sphere((0, 0, 0), radius)
 
+    def get_urdf_element(self):
+        attributes = {'radius': self.radius}
+        return URDFElement('sphere', attributes)
+
     @property
     def data(self):
         return {
@@ -326,6 +354,10 @@ class Sphere(BaseShape):
         sph.data = data
         return sph
 
+    @classmethod
+    def from_geometry(cls, geometry):
+        return cls(geometry.radius)
+
 
 class Capsule(BaseShape):
     """3D shape primitive representing a capsule.
@@ -354,6 +386,10 @@ class Capsule(BaseShape):
         self.radius = float(radius)
         self.length = float(length)
 
+    def get_urdf_element(self):
+        attributes = {'radius': self.radius, 'length': self.length}
+        return URDFElement('capsule', attributes)
+
     @property
     def data(self):
         return {
@@ -373,6 +409,10 @@ class Capsule(BaseShape):
         cap.data = data
         return cap
 
+    @classmethod
+    def from_geometry(cls, geometry):
+        return cls(geometry.radius, geometry.length)
+
 
 class MeshDescriptor(BaseShape):
     """Description of a mesh.
@@ -403,6 +443,16 @@ class MeshDescriptor(BaseShape):
         self.filename = filename
         self.scale = _parse_floats(scale)
 
+    def get_urdf_element(self):
+        attributes = {'filename': self.filename}
+        # There is no need to record default values.  Usually these
+        # coincide with some form of 0 and are filtered out with
+        # `attributes = dict(filter(lambda x: x[1], attributes.items()))`,
+        # but here we must be explicit.
+        if self.scale != [1.0, 1.0, 1.0]:
+            attributes['scale'] = "{} {} {}".format(*self.scale)
+        return URDFElement('mesh', attributes)
+
     @property
     def data(self):
         return {
@@ -449,6 +499,10 @@ class Color(Base):
         super(Color, self).__init__()
         self.rgba = _parse_floats(rgba)
 
+    def get_urdf_element(self):
+        attributes = {'rgba': "{} {} {} {}".format(*self.rgba)}
+        return URDFElement('color', attributes)
+
     @property
     def data(self):
         return {
@@ -501,6 +555,10 @@ class Texture(Base):
         super(Texture, self).__init__()
         self.filename = filename
 
+    def get_urdf_element(self):
+        attributes = {'filename': self.filename}
+        return URDFElement('texture', attributes)
+
     @property
     def data(self):
         return {
@@ -557,6 +615,11 @@ class Material(Base):
         self.color = color
         self.texture = texture
 
+    def get_urdf_element(self):
+        attributes = {'name': self.name}
+        elements = [self.color, self.texture]
+        return URDFElement('material', attributes, elements)
+
     @property
     def data(self):
         return {
@@ -666,6 +729,11 @@ class Geometry(Base):
         if 'geometry' not in dir(self.shape):
             raise TypeError('Shape implementation does not define a geometry accessor')
 
+    def get_urdf_element(self):
+        attributes = self.attr.copy()
+        elements = [self.shape]
+        return URDFElement('geometry', attributes, elements)
+
     @property
     def data(self):
         return {
